[pkg-wine-party] [SCM] Debian Wine packaging branch, wheezy, updated. wine-1.4-7-302-gb61b690

Alexandre Julliard julliard at winehq.org
Sun Jun 17 20:03:24 UTC 2012


The following commit has been merged in the wheezy branch:
commit 6c3c39f9902f04793fd51a7113ac9fc4010b3ef3
Author: Daniel Lehman <dlehman at esri.com>
Date:   Wed Apr 18 13:01:56 2012 -0700

    oleaut32: Treat years 0 to 29 as 2000 to 2029 in VARIANT_RollUdate.
    (cherry picked from commit cc37abb6589a1aa9862624c77a45b32c9a36dca1)

diff --git a/dlls/oleaut32/variant.c b/dlls/oleaut32/variant.c
index 0d1f2cc..2d6e2ce 100644
--- a/dlls/oleaut32/variant.c
+++ b/dlls/oleaut32/variant.c
@@ -1143,8 +1143,11 @@ static HRESULT VARIANT_RollUdate(UDATE *lpUd)
 
   if (iYear > 9999 || iYear < -9999)
     return E_INVALIDARG; /* Invalid value */
-  /* Years < 100 are treated as 1900 + year */
-  if (iYear > 0 && iYear < 100)
+  /* Year 0 to 29 are treated as 2000 + year */
+  if (iYear >= 0 && iYear < 30)
+    iYear += 2000;
+  /* Remaining years < 100 are treated as 1900 + year */
+  else if (iYear >= 30 && iYear < 100)
     iYear += 1900;
 
   iMinute += iSecond / 60;

-- 
Debian Wine packaging



More information about the pkg-wine-party mailing list